@@ -30,12 +30,13 @@ from ubuntuone.platform.credentials import CredentialsManagementTool
 
 from ubuntuone.controlpanel import sd_client, replication_client
 from ubuntuone.controlpanel.logger import setup_logging, log_call
-from ubuntuone.controlpanel.web_client import (
+from ubuntuone.controlpanel.web_client import WebClient
+from ubuntu_sso.utils.webclient.common import (
     UnauthorizedError,
-    WebClient,
     WebClientError,
 )
 
+
 logger = setup_logging('backend')
 
 ACCOUNT_API = u"account/"
@@ -225,10 +226,17 @@ class ControlBackend(object):
             self.sd_client.set_status_changed_handler(cb)
             self.is_sd_client_handler_set = True
 
+    def remove_status_changed_handler(self, handler):
+        """Remove 'handler' from callbacks list."""
+        if handler in self._status_changed_handlers:
+            self._status_changed_handlers.remove(handler)
+
     @inlineCallbacks
     def _process_device_web_info(self, devices,
-        enabled=None, limit_bw=None, limits=None, autoconnect=None,
-        show_notifs=None, share_autosubscribe=None, udf_autosubscribe=None):
+                                 enabled=None, limit_bw=None,
+                                 limits=None, autoconnect=None,
+                                 show_notifs=None, share_autosubscribe=None,
+                                 udf_autosubscribe=None):
         """Return a lis of processed devices.
 
         If all the file sync settings are None, do not attach that info.
@@ -274,8 +282,10 @@ class ControlBackend(object):
 
     @inlineCallbacks
     def _process_device_local_info(self,
-        enabled=None, limit_bw=None, limits=None, autoconnect=None,
-        show_notifs=None, share_autosubscribe=None, udf_autosubscribe=None):
+                                   enabled=None, limit_bw=None,
+                                   limits=None, autoconnect=None,
+                                   show_notifs=None, share_autosubscribe=None,
+                                   udf_autosubscribe=None):
         """Return the information for the local device.
 
         If all the file sync settings are None, do not attach that info.
@@ -881,6 +891,13 @@ class ControlBackend(object):
             handler)
         returnValue(result)
 
+    @log_call(logger.info)
+    @inlineCallbacks
+    def search_files(self, pattern):
+        """Search for this pattern in the name of u1 files."""
+        result = yield self.sd_client.search_files(pattern)
+        returnValue(result)
+
     @log_call(logger.info)
     def shutdown(self):
         """Stop this service."""
