@@ -148,7 +148,7 @@ class MockBackend(object):
 
     def __init__(self, shutdown_func=None):
         MockBackend.shutdown_func = shutdown_func
-        self._status_changed_handler = []
+        self._status_changed_handlers = []
 
     def _process(self, result):
         """Process the request with the given result."""
@@ -157,23 +157,10 @@ class MockBackend(object):
             return defer.fail(self.exception(result))
         return defer.succeed(result)
 
-    def _set_status_changed_handler(self, handler):
+    def add_status_changed_handler(self, handler):
         """Set 'handler' to be called when file sync status changes."""
-        if handler is not None:
-            self._status_changed_handler.append(handler)
-        else:
-            self._status_changed_handler = []
-
-    def _get_status_changed_handler(self):
-        """Return the handler to be called when file sync status changes."""
-        if len(self._status_changed_handler) > 0:
-            result = self._status_changed_handler[-1]
-        else:
-            result = None
-        return result
-
-    status_changed_handler = property(_get_status_changed_handler,
-                                      _set_status_changed_handler)
+        if handler not in self._status_changed_handlers:
+            self._status_changed_handlers.append(handler)
 
     def account_info(self):
         """Get the user account info."""
@@ -751,29 +738,29 @@ class FileSyncTestCase(BaseTestCase):
             return self.assert_correct_status_signal(*args, expected_msg=arg)
 
     def test_status_changed_handler(self):
-        """The status changed handler is properly set."""
+        """There is no default status changed handler."""
         be = MockBackend()
         dbus_service.ControlPanelBackend(backend=be)
-
-        self.assertEqual(be.status_changed_handler, None)
+        # pylint: disable=W0212
+        self.assertEqual(be._status_changed_handlers, [])
 
     def test_status_changed_handler_after_status_requested(self):
-        """The status changed handler is properly set."""
+        """file_sync_status sets the callback in the CP backend."""
         be = MockBackend()
         cpbe = dbus_service.ControlPanelBackend(backend=be)
         cpbe.file_sync_status()
-
-        self.assertEqual(be.status_changed_handler, cpbe.process_status)
+        # pylint: disable=W0212
+        self.assertEqual(be._status_changed_handlers, [cpbe.process_status])
 
     def test_status_changed_handler_after_status_requested_twice(self):
-        """The status changed handler is properly set."""
+        """The Handler is only added once after 2 calls to file_sync_status."""
         be = MockBackend()
         cpbe = dbus_service.ControlPanelBackend(backend=be)
         cpbe.file_sync_status()
         cpbe.file_sync_status()
 
         # pylint: disable=W0212
-        self.assertEqual(be._status_changed_handler, [cpbe.process_status])
+        self.assertEqual(be._status_changed_handlers, [cpbe.process_status])
 
 
 class ShutdownTestCase(BaseTestCase):
