@@ -36,12 +36,12 @@ from ubuntuone.controlpanel.gui import (
     IN_PROGRESS,
     IN_PROGRESS_FILE,
     LOADING,
-    NEW_SHARE_BY,
     OPEN_UBUNTU_ONE,
     OPEN_UBUNTU_ONE_FOLDER,
     PLEASE_WAIT,
     RECENT_TRANSFERS,
     RECENTTRANSFERS,
+    SHARE_A_FILE,
     TRANSFERS,
     UPLOADING,
 )
@@ -122,6 +122,7 @@ class TrayIcon(QtGui.QSystemTrayIcon, cache.Cache):
         self.quit = None
         self.get_help_online = None
         self.open_u1 = None
+        self.share_a_file = None
         self.status_action = None
         self.go_to_web = None
         self.get_more_storage = None
@@ -130,75 +131,48 @@ class TrayIcon(QtGui.QSystemTrayIcon, cache.Cache):
         self.backend.add_status_changed_handler(self._process_status)
 
         self.load_menu()
-        # Refresh the Shares every five minutes if needed.
-        self._timer_id = self.startTimer(300000)
 
-    # pylint: disable=C0103
-
-    def timerEvent(self, event):
-        """Update the menu on each iteration."""
-        self.load_menu()
-
-    # pylint: enable=C0103
-
-    @inlineCallbacks
     def load_menu(self):
         """Load the content of the menu."""
-        shares_info = yield self.backend.get_shares()
-        shares_info = [share for share in shares_info if not share['accepted']]
-        if shares_info != self._previous_shares:
-            # Items
-            self.context_menu.clear()
+        # Items
+        self.context_menu.clear()
 
-            self.status = self.context_menu.addAction(LOADING)
-            self.status.setEnabled(False)
-            self.status_action = self.context_menu.addAction(PLEASE_WAIT)
-            self.refresh_status()
-            self.context_menu.addSeparator()
+        self.status = self.context_menu.addAction(LOADING)
+        self.status.setEnabled(False)
+        self.status_action = self.context_menu.addAction(PLEASE_WAIT)
+        self.refresh_status()
+        self.context_menu.addSeparator()
 
-            self.open_u1 = self.context_menu.addAction(OPEN_UBUNTU_ONE)
-            # TODO: Share a file action when the Shares tab is ready in U1-CP
-            self.open_u1_folder = self.context_menu.addAction(
-                OPEN_UBUNTU_ONE_FOLDER)
-            self.go_to_web = self.context_menu.addAction(GO_TO_WEB)
-            self.context_menu.addSeparator()
+        self.open_u1 = self.context_menu.addAction(OPEN_UBUNTU_ONE)
+        self.share_a_file = self.context_menu.addAction(SHARE_A_FILE)
+        self.open_u1_folder = self.context_menu.addAction(
+            OPEN_UBUNTU_ONE_FOLDER)
+        self.go_to_web = self.context_menu.addAction(GO_TO_WEB)
+        self.context_menu.addSeparator()
 
-            # Shares
-            self._previous_shares = shares_info
-            max_shares = 0
-            for share in self._previous_shares:
-                if max_shares == 3:
-                    break
-                max_shares += 1
-                text = NEW_SHARE_BY % share['other_visible_name']
-                share_action = SharesAction(text, share['volume_id'],
-                    self.context_menu)
-                self.context_menu.addAction(share_action)
-            if self._previous_shares:
-                self.context_menu.addSeparator()
+        # Transfers
+        self.transfers = TransfersMenu(self)
+        self.context_menu.addMenu(self.transfers)
 
-            # Transfers
-            self.transfers = TransfersMenu(self)
-            self.context_menu.addMenu(self.transfers)
+        self.get_more_storage = self.context_menu.addAction(
+            GET_MORE_STORAGE)
+        self.get_help_online = self.context_menu.addAction(GET_HELP_ONLINE)
+        self.quit = self.context_menu.addAction("Quit")
 
-            self.get_more_storage = self.context_menu.addAction(
-                GET_MORE_STORAGE)
-            self.get_help_online = self.context_menu.addAction(GET_HELP_ONLINE)
-            self.quit = self.context_menu.addAction("Quit")
+        self.setContextMenu(self.context_menu)
 
-            self.setContextMenu(self.context_menu)
+        # Connect Signals
+        self.status_action.triggered.connect(self.change_status)
+        self.open_u1.triggered.connect(self.restore_window)
+        self.share_a_file.triggered.connect(self.open_share_tab)
+        self.open_u1_folder.triggered.connect(self.open_u1_folder_action)
+        self.get_more_storage.triggered.connect(
+            self.get_more_storage_action)
+        self.go_to_web.triggered.connect(self.go_to_web_action)
+        self.get_help_online.triggered.connect(self.get_help_action)
+        self.quit.triggered.connect(self.stop)
 
-            # Connect Signals
-            self.status_action.triggered.connect(self.change_status)
-            self.open_u1.triggered.connect(self.restore_window)
-            self.open_u1_folder.triggered.connect(self.open_u1_folder_action)
-            self.get_more_storage.triggered.connect(
-                self.get_more_storage_action)
-            self.go_to_web.triggered.connect(self.go_to_web_action)
-            self.get_help_online.triggered.connect(self.get_help_action)
-            self.quit.triggered.connect(self.stop)
-
-            self._get_volumes_info()
+        self._get_volumes_info()
 
     @inlineCallbacks
     def refresh_status(self):
@@ -278,6 +252,17 @@ class TrayIcon(QtGui.QSystemTrayIcon, cache.Cache):
         self.window.show()
         self.window.activateWindow()
 
+    def open_share_tab(self):
+        """Show the main window in the share tab."""
+        if self.window is None:
+            # pylint: disable=W0404
+            from ubuntuone.controlpanel.gui.qt.gui import MainWindow
+            # pylint: enable=W0404
+            self.window = MainWindow(close_callback=self.delete_window)
+        self.window.switch_to('share_links')
+        self.window.show()
+        self.window.activateWindow()
+
     def delete_window(self):
         """Close and remove the main window."""
         if self.window is not None:
