@@ -28,13 +28,72 @@ from ubuntuone.controlpanel.gui import (
     GENERAL_ERROR_TITLE,
     GENERAL_ERROR_MSG,
 )
-from ubuntuone.controlpanel.gui.qt import uri_hook, handle_errors
+from ubuntuone.controlpanel.gui.qt import (
+    force_wordwrap,
+    handle_errors,
+    uri_hook,
+)
 from ubuntuone.controlpanel.gui.qt.tests import (
     BaseTestCase,
     FakedDialog,
 )
 
 
+class ForceWordWrapTestCase(BaseTestCase):
+    """The test suite for the force_wordwrap."""
+
+    @defer.inlineCallbacks
+    def setUp(self):
+        yield super(ForceWordWrapTestCase, self).setUp()
+        self.check = QtGui.QCheckBox()
+
+    def test_small_text_no_wordwrap(self):
+        """Set a small text, the widget shouldn't wordwrap."""
+        text = u'small text'
+        force_wordwrap(self.check, 1000, text)
+        self.assertEqual(unicode(self.check.text()), text)
+
+    def test_size_invalid(self):
+        """The text shouldn't change if the size is not valid."""
+        text = u'small text' * 20
+        force_wordwrap(self.check, 0, text)
+        self.assertEqual(unicode(self.check.text()), text)
+
+    def test_size_too_small(self):
+        """The text shouldn't change if the size is too small."""
+        text = u'small text' * 20
+        force_wordwrap(self.check, 10, text)
+        self.assertEqual(unicode(self.check.text()), text)
+
+    def test_check_wrapping(self):
+        """The text should be splitted in several lines."""
+        text = u'small text ' * 20
+        font_metrics = QtGui.QFontMetrics(self.check.font())
+        size = font_metrics.width('small text')
+        force_wordwrap(self.check, size, text)
+        expected = u'small text \n' * 20
+        expected = expected[:-1]
+        self.assertEqual(unicode(self.check.text()), expected.rstrip())
+
+    def test_check_wrapping_in_the_middle_of_word(self):
+        """The text should be splitted in several lines."""
+        text = u'small text ' * 20
+        font_metrics = QtGui.QFontMetrics(self.check.font())
+        size = font_metrics.width('small text')
+        force_wordwrap(self.check, size, text)
+        expected = u'small text \n' * 20
+        expected = expected[:-1]
+        self.assertEqual(unicode(self.check.text()), expected.rstrip())
+
+    def test_no_word_wrap_valid(self):
+        """If a not valid wrap place is found, the word wrap is not made."""
+        text = u'smalltext ' * 20
+        font_metrics = QtGui.QFontMetrics(self.check.font())
+        size = font_metrics.averageCharWidth() * 5
+        force_wordwrap(self.check, size, text)
+        self.assertEqual(unicode(self.check.text()), text.rstrip())
+
+
 class UriHookTestCase(BaseTestCase):
     """The test suite for the uri_hook."""
 
