@@ -74,6 +74,14 @@ class ControlPanelTestCase(UbuntuOneBinTestCase):
         self.assertIs(self.ui.ui.switcher.currentWidget(), self.ui.ui.wizard)
         self.assertEqual(self._called, ((), {}))
 
+    def test_on_credentials_not_found_sets_folder_tab(self):
+        """Credentials_not_found should switch to the folder tab."""
+        unexpected = self.ui.ui.tab_widget.indexOf(self.ui.ui.devices_tab)
+        expected = self.ui.ui.tab_widget.indexOf(self.ui.ui.folders_tab)
+        self.ui.ui.tab_widget.setCurrentIndex(unexpected)
+        self.ui.on_credentials_not_found()
+        self.assertEqual(self.ui.ui.tab_widget.currentIndex(), expected)
+
     @defer.inlineCallbacks
     def test_on_credentials_found_called(self):
         """If credentials, on_credentials_not_found is called."""
@@ -83,10 +91,9 @@ class ControlPanelTestCase(UbuntuOneBinTestCase):
         self.assertEqual(self._called, ((), {}))
 
     def test_on_credentials_found(self):
-        """The management panel is shown."""
+        """File sync is connected and the management panel is shown."""
         self.patch(self.ui, 'connect_file_sync', self._set_called)
-        self.ui.on_credentials_not_found()
-        self.ui.on_credentials_found()
+        yield self.ui.on_credentials_found()
 
         self.assertIs(self.ui.ui.switcher.currentWidget(),
                       self.ui.ui.management)
@@ -146,7 +153,7 @@ class ControlPanelTestCase(UbuntuOneBinTestCase):
 
     def test_on_wizard_finished(self):
         """When the wizard is finished, the management panel is shown."""
-        self.patch(self.ui, 'on_credentials_found', self._set_called)
+        self.patch(self.ui, 'show_management_ui', self._set_called)
         self.ui.ui.wizard.finished.emit(1)
 
         self.assertEqual(self._called, ((), {}))
