@@ -54,9 +54,9 @@ from ubuntuone.controlpanel.gui.qt.tests.test_ubuntuonebin import (
 # pylint: disable=W0212, E1103
 
 DEFAULT_FOLDERS = [u'Music', u'Configuración', 'An invalid folder',
-    os.path.join(u'I ♥ Ubuntu', u'Documents'),
-    os.path.join(u'I ♥ Ubuntu', u'Something', u'Long'),
-]
+                   os.path.join(u'I ♥ Ubuntu', u'Documents'),
+                   os.path.join(u'I ♥ Ubuntu', u'Something', u'Long'),
+                   ]
 
 
 def volumes_with_music_unsubscribed():
@@ -1133,8 +1133,8 @@ class LocalFoldersPanelTestCase(BaseLocalFoldersPanelTestCase):
         volumes = sorted(volumes, key=operator.itemgetter('path'))
 
         for volume in volumes:
-            if (volume['type'] != self.ui.backend.FOLDER_TYPE or
-                not bool(volume['subscribed'])):
+            if volume['type'] != self.ui.backend.FOLDER_TYPE or \
+                    not bool(volume['subscribed']):
                 # non-folders or unsubscribed should not appear in the tree
                 continue
             self.assert_folder_added(volume['path'],
@@ -1319,6 +1319,7 @@ class LocalFoldersPanelApplyChangesTestCase(BaseLocalFoldersPanelTestCase):
         yield self.changes_applied
         self.assertEqual(self.ui.backend._called, {})
 
+    @defer.inlineCallbacks
     def test_timer_is_stopped(self):
         """When applying changes, timer is stopped."""
         yield self.ui.apply_changes()
