@@ -20,6 +20,8 @@
 
 from __future__ import division
 
+import operator
+
 from twisted.internet import defer
 
 from ubuntuone.controlpanel.gui.qt import preferences as gui
@@ -45,16 +47,22 @@ class PreferencesPanelTestCase(UbuntuOneBinTestCase):
         notifs = self.ui.ui.show_all_notifications_checkbox.checkState()
         share_auto = self.ui.ui.share_autosubscribe_checkbox.checkState()
         udf_auto = self.ui.ui.udf_autosubscribe_checkbox.checkState()
-        download_speed = self.ui.ui.download_speed_spinbox.value()
-        upload_speed = self.ui.ui.upload_speed_spinbox.value()
+        if self.ui.ui.limit_downloads_checkbox.checkState() == gui.CHECKED:
+            download_speed = self.ui.ui.download_speed_spinbox.value()
+        else:
+            download_speed = -1
+        if self.ui.ui.limit_uploads_checkbox.checkState() == gui.CHECKED:
+            upload_speed = self.ui.ui.upload_speed_spinbox.value()
+        else:
+            upload_speed = -1
 
         result = {
             gui.backend.AUTOCONNECT_KEY: autoconnect == gui.CHECKED,
             gui.backend.SHOW_ALL_NOTIFICATIONS_KEY: notifs == gui.CHECKED,
             gui.backend.SHARE_AUTOSUBSCRIBE_KEY: share_auto == gui.CHECKED,
             gui.backend.UDF_AUTOSUBSCRIBE_KEY: udf_auto == gui.CHECKED,
-            gui.backend.DOWNLOAD_KEY: gui.tweak_speed(download_speed),
-            gui.backend.UPLOAD_KEY: gui.tweak_speed(upload_speed),
+            gui.backend.DOWNLOAD_KEY: download_speed * gui.KILOBYTES,
+            gui.backend.UPLOAD_KEY: upload_speed * gui.KILOBYTES,
         }
         return result
 
@@ -118,18 +126,20 @@ class PreferencesPanelTestCase(UbuntuOneBinTestCase):
         speed = settings[gui.backend.DOWNLOAD_KEY]
         if speed > 0:
             speed = settings[gui.backend.DOWNLOAD_KEY] // gui.KILOBYTES
-        download_speed = self.ui.ui.download_speed_spinbox.value()
-        self.assertEqual(speed, download_speed)
+            download_speed = self.ui.ui.download_speed_spinbox.value()
+            self.assertEqual(speed, download_speed)
         limit_downloads = self.ui.ui.limit_downloads_checkbox.checkState()
-        self.assertEqual(speed > 0, limit_downloads == gui.CHECKED)
+        self.assertEqual(self.ui.ui.download_speed_spinbox.isEnabled(),
+            limit_downloads == gui.CHECKED)
 
         speed = settings[gui.backend.UPLOAD_KEY]
         if speed > 0:
             speed = settings[gui.backend.UPLOAD_KEY] // gui.KILOBYTES
-        upload_speed = self.ui.ui.upload_speed_spinbox.value()
-        self.assertEqual(speed, upload_speed)
+            upload_speed = self.ui.ui.upload_speed_spinbox.value()
+            self.assertEqual(speed, upload_speed)
         limit_uploads = self.ui.ui.limit_uploads_checkbox.checkState()
-        self.assertEqual(speed > 0, limit_uploads == gui.CHECKED)
+        self.assertEqual(self.ui.ui.upload_speed_spinbox.isEnabled(),
+            limit_uploads == gui.CHECKED)
 
     def test_update_ui_from_backed_info(self):
         """The ui is correctly updated when the backend info is received."""
@@ -151,63 +161,22 @@ class PreferencesPanelTestCase(UbuntuOneBinTestCase):
         self.ui.process_info(settings)
         self._test_update_ui_from_settings_info(settings)
 
-    def _test_speed_checkbox_value_changed_to_positive(self, speed_spinbox,
-                                                       limit_checkbox):
-        """When the speed is set to a positive value, enable the checkbox."""
-        limit_checkbox.setCheckState(gui.UNCHECKED)
-        speed_spinbox.setValue(33)
-
-        self.assertEqual(gui.CHECKED, limit_checkbox.checkState())
-
-    def _test_speed_checkbox_value_changed_to_negative(self, speed_spinbox,
-                                                       limit_checkbox):
-        """When the speed is set to a negative value, disable the checkbox."""
-        limit_checkbox.setCheckState(gui.UNCHECKED)
-        speed_spinbox.setValue(-1)
-
-        self.assertEqual(gui.UNCHECKED, limit_checkbox.checkState())
-
-    def _test_speed_checkbox_unchecked(self, speed_spinbox, limit_checkbox):
-        """When the speed checkbox is unchecked, reset speed to -1."""
+    def _test_speed_checkbox_toggled(self, speed_spinbox, limit_checkbox):
+        """The checkbox is checked if and only if the spinbox is enabled."""
         limit_checkbox.setCheckState(gui.CHECKED)
-        speed_spinbox.setValue(33)
+        self.assertTrue(speed_spinbox.isEnabled())
         limit_checkbox.setCheckState(gui.UNCHECKED)
+        self.assertFalse(speed_spinbox.isEnabled())
 
-        self.assertEqual(-1, speed_spinbox.value())
-
-    def test_download_speed_checkbox_value_changed_to_positive(self):
-        """When the download speed is set, enable the checkbox."""
-        self._test_speed_checkbox_value_changed_to_positive(
+    def test_download_speed_checkbox_connections(self):
+        """Check connections for download_speed_checkbox."""
+        self._test_speed_checkbox_toggled(
             self.ui.ui.download_speed_spinbox,
             self.ui.ui.limit_downloads_checkbox)
 
-    def test_download_speed_checkbox_value_changed_to_negative(self):
-        """When the download speed is set, enable the checkbox."""
-        self._test_speed_checkbox_value_changed_to_negative(
-            self.ui.ui.download_speed_spinbox,
-            self.ui.ui.limit_downloads_checkbox)
-
-    def test_download_speed_checkbox_unchecked(self):
-        """Reset the speed to -1 when the checkbox is disabled."""
-        self._test_speed_checkbox_unchecked(
-            self.ui.ui.download_speed_spinbox,
-            self.ui.ui.limit_downloads_checkbox)
-
-    def test_upload_speed_checkbox_value_changed_to_positive(self):
-        """When the upload speed is set, enable the checkbox."""
-        self._test_speed_checkbox_value_changed_to_positive(
-            self.ui.ui.upload_speed_spinbox,
-            self.ui.ui.limit_uploads_checkbox)
-
-    def test_upload_speed_checkbox_value_changed_to_negative(self):
-        """When the upload speed is set, enable the checkbox."""
-        self._test_speed_checkbox_value_changed_to_negative(
-            self.ui.ui.upload_speed_spinbox,
-            self.ui.ui.limit_uploads_checkbox)
-
-    def test_upload_speed_checkbox_unchecked(self):
-        """Reset the speed to -1 when the checkbox is disabled."""
-        self._test_speed_checkbox_unchecked(
+    def test_upload_speed_checkbox_connections(self):
+        """Check connections for upload_speed_checkbox."""
+        self._test_speed_checkbox_toggled(
             self.ui.ui.upload_speed_spinbox,
             self.ui.ui.limit_uploads_checkbox)
 
@@ -286,14 +255,29 @@ class PreferencesPanelTestCase(UbuntuOneBinTestCase):
 
         yield self.ui.ui.restore_defaults_button.click()
 
-    def test_tweak_speed_negative(self):
-        """Tweak speed properly: if param is negative, return -1."""
-        self.assertEqual(-1, gui.tweak_speed(-5))
-
-    def test_tweak_speed_zero(self):
-        """Tweak speed properly: if param is zero, return 1."""
-        self.assertEqual(1, gui.tweak_speed(0))
-
-    def test_tweak_speed_positive(self):
-        """Tweak speed properly: if param is positive, return kilobytes."""
-        self.assertEqual(123456 * gui.KILOBYTES, gui.tweak_speed(123456))
+    def test_resize_event(self):
+        """Check that the QCheckBox widgets receive the proper texts."""
+        wrap_calls = {}
+        self.patch(gui, "force_wordwrap",
+            lambda check, size, text: operator.setitem(
+                wrap_calls, check, (size, text)))
+        self.ui.setFixedWidth(1000)
+        size_bandwidth = (self.ui.ui.bandwidth_settings.width() -
+            self.ui.ui.upload_speed_spinbox.width())
+        padding = 160  # Left and Right Padding
+        size_sync = (self.ui.ui.file_sync_settings.width() - padding)
+        self.ui.show()
+        self.addCleanup(self.ui.hide)
+        self.assertEqual(wrap_calls[self.ui.ui.limit_uploads_checkbox],
+            (size_bandwidth, gui.SETTINGS_LIMIT_UPLOAD))
+        self.assertEqual(wrap_calls[self.ui.ui.limit_downloads_checkbox],
+            (size_bandwidth, gui.SETTINGS_LIMIT_DOWNLOAD))
+        self.assertEqual(wrap_calls[self.ui.ui.autoconnect_checkbox],
+            (size_sync, gui.SETTINGS_AUTO_CONNECT))
+        self.assertEqual(wrap_calls[self.ui.ui.udf_autosubscribe_checkbox],
+            (size_sync, gui.SETTINGS_SYNC_ALL_SHARES))
+        self.assertEqual(wrap_calls[self.ui.ui.share_autosubscribe_checkbox],
+            (size_sync, gui.SETTINGS_SYNC_ALL_FOLDERS))
+        self.assertEqual(
+            wrap_calls[self.ui.ui.show_all_notifications_checkbox],
+            (size_sync, gui.SETTINGS_ALLOW_NOTIFICATIONS))
