@@ -16,13 +16,12 @@
 
 """Tests for the control panel backend."""
 
+import json
 import operator
 import os
 
 from collections import defaultdict
 
-import simplejson
-
 from twisted.internet import defer
 from twisted.internet.defer import inlineCallbacks, returnValue
 from ubuntuone.devtools.handlers import MementoHandler
@@ -43,7 +42,8 @@ from ubuntuone.controlpanel.backend import (
     UBUNTUONE_FROM_OAUTH,
     UBUNTUONE_LINK,
 )
-from ubuntuone.controlpanel.tests import (TestCase,
+from ubuntuone.controlpanel.tests import (
+    TestCase,
     EMPTY_DESCRIPTION_JSON,
     EXPECTED_ACCOUNT_INFO,
     EXPECTED_ACCOUNT_INFO_WITH_CURRENT_PLAN,
@@ -106,7 +106,7 @@ class MockWebClient(CallRecorder):
         elif self.failure:
             return defer.fail(backend.WebClientError(self.failure))
         else:
-            result = simplejson.loads(self.results[method])
+            result = json.loads(self.results[method])
             return defer.succeed(result)
 
     @defer.inlineCallbacks
@@ -170,6 +170,7 @@ class MockSDClient(CallRecorder):
         self.folders = []
         self.volumes_refreshed = False
         self.menu_data = {'recent-transfers': (), 'uploading': ()}
+        self.files_search = ['/home/u1/path/my_file', '/home/u1/path/test']
         self.publicfiles = [
             {'path': '/home/file1', 'public_url': 'http:ubuntuone.com/asd123'},
             {'path': '/home/file2', 'public_url': 'http:ubuntuone.com/qwe456'},
@@ -340,6 +341,10 @@ class MockSDClient(CallRecorder):
         """Return the sync menu data."""
         return self.menu_data
 
+    def search_files(self, pattern):
+        """Return the search files results."""
+        return [file_ for file_ in self.files_search if pattern in file_]
+
     def get_public_files(self):
         """Trigger the action to get the public files."""
         if self.public_files_list_handler is not None:
@@ -1056,7 +1061,7 @@ class BackendVolumesTestCase(BackendBasicTestCase):
                 assert sid not in expected
                 expected[sid] = volume
 
-        _ = yield self.be.volumes_info()
+        yield self.be.volumes_info()
 
         self.assertEqual(len(self.be._volumes), len(expected))
         self.assertEqual(self.be._volumes, expected)
@@ -1480,6 +1485,32 @@ class BackendSyncStatusTestCase(BackendBasicTestCase):
         self.assertEqual(self.call_count_b, 1)
         self.assertEqual(self.call_count_a, 1)
 
+    def test_remove_status_handler(self):
+        """Test removing a handler."""
+        self.call_count_a = 0
+        self.call_count_b = 0
+
+        def inc_a(status):
+            """Fake status handler #1"""
+            self.call_count_a += 1
+
+        def inc_b(status):
+            """Fake status handler #2"""
+            self.call_count_b += 1
+
+        self.addCleanup(delattr, self, "call_count_a")
+        self.addCleanup(delattr, self, "call_count_b")
+
+        self.be.add_status_changed_handler(inc_a)
+        self.be.add_status_changed_handler(inc_b)
+
+        self.be.sd_client.status_changed_handler({})
+        self.be.remove_status_changed_handler(inc_b)
+        self.be.sd_client.status_changed_handler({})
+
+        self.assertEqual(self.call_count_b, 1)
+        self.assertEqual(self.call_count_a, 2)
+
 
 class BackendSyncStatusIfDisabledTestCase(BackendSyncStatusTestCase):
     """Syncdaemon state for the backend when file sync is disabled."""
@@ -1807,6 +1838,16 @@ class BackendFileSyncSettingsTestCase(BackendBasicTestCase):
         expected = {'recent-transfers': (), 'uploading': ()}
         self.assertEqual(result, expected)
 
+    @inlineCallbacks
+    def test_search_files(self):
+        """Check that we get the right data to create the menu."""
+        result = yield self.be.search_files('file')
+        expected = ['/home/u1/path/my_file']
+        self.assertEqual(result, expected)
+        result = yield self.be.search_files('test')
+        expected = ['/home/u1/path/test']
+        self.assertEqual(result, expected)
+
     @inlineCallbacks
     def test_get_public_files(self):
         """Check that we get list of public files."""
