@@ -19,14 +19,14 @@
 from urlparse import urlparse, parse_qs
 
 from twisted.internet import defer
-from twisted.web import resource
+from twisted.web import http, resource
 
 from ubuntuone.devtools.testing.txwebserver import HTTPWebServer
 
 from ubuntuone.controlpanel.tests import TestCase
-from ubuntuone.controlpanel.web_client import (
+from ubuntuone.controlpanel.web_client import WebClient
+from ubuntu_sso.utils.webclient.common import (
     UnauthorizedError,
-    WebClient,
     WebClientError,
 )
 from ubuntuone.platform.credentials import APP_NAME
@@ -83,7 +83,7 @@ class MockWebServer(HTTPWebServer):
         devices_resource.contents = SAMPLE_RESOURCE
         root.putChild("devices", devices_resource)
         root.putChild("throwerror", resource.NoResource())
-        unauthorized = resource.ErrorPage(resource.http.UNAUTHORIZED,
+        unauthorized = resource.ErrorPage(http.UNAUTHORIZED,
                                           "Unauthrorized", "Unauthrorized")
         root.putChild("unauthorized", unauthorized)
         super(MockWebServer, self).__init__(root)
